#import "FacebookAppEventsPlugin.h"
#import <FBSDKCoreKit/FBSDKCoreKit.h>

@implementation FacebookAppEventsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter.oddbit.id/facebook_app_events"
            binaryMessenger:[registrar messenger]];
  FacebookAudienceNetworkPlugin* instance = [[FacebookAudienceNetworkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"logEvent" isEqualToString:call.method]) {
    [self handleLogEvent:call result:result];
  } else if ([@"xxx" isEqualToString:call.method]) {
    [self handleXXXX:call result:result];
  } else if ([@"yyy" isEqualToString:call.method]) {
    [self handleYYY:call result:result];
  } else if ([@"zzz" isEqualToString:call.method]) {
    [self handlZZZZ:call result:result];
  } else {
    result(FlutterMethodNotImplemented);
  }
}

- (void)handleLogEvent:(FlutterMethodCall *)call result:(FlutterResult)result {
  NSString *eventName = call.arguments[@"name"];
  id parameterMap = call.arguments[@"parameters"];
  id valueToSum = call.arguments[@"valueToSum"];

  if (parameterMap != [NSNull null] && valueToSum != [NSNull null]) {
      [FBSDKAppEvents logEvent:eventName parameters:parameterMap valueToSum:valueToSum];
  } else if (parameterMap != [NSNull null]) {
      [FBSDKAppEvents logEvent:eventName parameters:parameterMap];
  } else if (valueToSum != [NSNull null]) {
      [FBSDKAppEvents logEvent:eventName valueToSum:valueToSum];
  } else {
      [FBSDKAppEvents logEvent:eventName];
  }

  result(nil);
}

- (void)handleXXXX:(FlutterMethodCall *)call result:(FlutterResult)result {
  
  result(nil);
}

- (void)handleYYY:(FlutterMethodCall *)call result:(FlutterResult)result {
  
  result(nil);
}

- (void)handlZZZZ:(FlutterMethodCall *)call result:(FlutterResult)result {
  
  result(nil);
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
  if ([@"logEvent" isEqualToString:call.method]) {
    NSString *eventName = call.arguments[@"name"];
    id parameterMap = call.arguments[@"parameters"];

    if (parameterMap != [NSNull null]) {
      [FIRAnalytics logEventWithName:eventName parameters:parameterMap];
    } else {
      [FIRAnalytics logEventWithName:eventName parameters:nil];
    }

    result(nil);
  } else if ([@"setUserId" isEqualToString:call.method]) {
    NSString *userId = call.arguments;
    [FIRAnalytics setUserID:userId];
    result(nil);
  } else if ([@"setCurrentScreen" isEqualToString:call.method]) {
    NSString *screenName = call.arguments[@"screenName"];
    NSString *screenClassOverride = call.arguments[@"screenClassOverride"];
    [FIRAnalytics setScreenName:screenName screenClass:screenClassOverride];
    result(nil);
  } else if ([@"setUserProperty" isEqualToString:call.method]) {
    NSString *name = call.arguments[@"name"];
    NSString *value = call.arguments[@"value"];
    [FIRAnalytics setUserPropertyString:value forName:name];
    result(nil);
  } else if ([@"setAnalyticsCollectionEnabled" isEqualToString:call.method]) {
    NSNumber *enabled = call.arguments;
    [FIRAnalytics setAnalyticsCollectionEnabled:[enabled boolValue]];
    result(nil);
  } else if ([@"resetAnalyticsData" isEqualToString:call.method]) {
    [FIRAnalytics resetAnalyticsData];
    result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end